#!/usr/bin/env python3

import asyncio
import argparse
import textwrap
from pywizlight.bulb import wizlight, PilotBuilder

class Wizcon():
    def __init__(self, ip):
        self.light = wizlight(ip)

    def __del__(self):
        del self.light

    async def turn_bulb_on(self):
        await self.light.turn_on(PilotBuilder())
    
    async def set_scene_id(self, scene_id):
        await self.light.turn_on(PilotBuilder(scene = scene_id))

    async def set_brightness(self, brightness_val):
        await self.light.turn_on(PilotBuilder(brightness = brightness_val))

    async def turn_bulb_off(self):
        await self.light.turn_off()
    
    async def switch_bulb(self):
        await self.light.lightSwitch()
    
    async def run(self, args):
        if args.COMMAND == 'ON':
            if (args.scene_id is not None and args.brightness is not None):
                await self.turn_bulb_on()
            elif (args.scene_id is not None):
                await self.set_scene_id(args.scene_id)
            elif (args.brightness is not None):
                await self.set_brightness(args.brightness)
        elif args.COMMAND == 'OFF':
            await self.turn_bulb_off()
        elif args.COMMAND == 'SWITCH':
            await self.switch_bulb()

def parse_args(args):
    parser = argparse.ArgumentParser(
        prog='wizcon',
        description='Control Philips WiZ Connected smart light bulbs',
        formatter_class=argparse.RawDescriptionHelpFormatter,
        epilog=textwrap.dedent('''\
        Scene Table
        1: "Ocean"
        2: "Romance"
        3: "Sunset"
        4: "Party"
        5: "Fireplace"
        6: "Cozy"
        7: "Forest"
        8: "Pastel Colors"
        9: "Wake up"
        10: "Bedtime"
        11: "Warm White"
        12: "Daylight"
        13: "Cool white"
        14: "Night light"
        15: "Focus"
        16: "Relax"
        17: "True colors"
        18: "TV time"
        19: "Plantgrowth"
        20: "Spring"
        21: "Summer"
        22: "Fall"
        23: "Deepdive"
        24: "Jungle"
        25: "Mojito"
        26: "Club"
        27: "Christmas"
        28: "Halloween"
        29: "Candlelight"
        30: "Golden white"
        31: "Pulse"
        32: "Steampunk"

        Examples

        Turn smart bulb on:
        wizcon 192.168.1.100 ON

        Turn smart bulb off:
        wizcon 192.168.1.100 OFF

        Switch smart bulb between on and off states:
        wizcon 192.168.1.100 SWITCH

        Set scene to "Deepdive" using scene ID:
        wizcon --scene_id 23 192.168.1.100 ON

        Set brightness to 255 (max brightness):
        wizcon --brightness 255 192.168.1.100 ON
        '''))
    parser.add_argument('IP', type=str, help='IP address of smart bulb')
    parser.add_argument('COMMAND', type=str.upper, choices=['ON', 'OFF', 'SWITCH'], help='Command sent to the smart bulb')
    parser.add_argument('-si', '--scene_id', type=int, choices=range(1,33), metavar='{1-32}', help='Set scene of smart bulb using scene ID')
    #parser.add_argument('-sn', '--scene_name', type=str, help='Set scene of smart bulb using scene name')
    #parser.add_argument('-c', '--color', type=str, help='Set color of smart bulb')
    parser.add_argument('-b', '--brightness', type=int, choices=range(0, 256), metavar='{0-255}', help='Set brightness of smart bulb')
    #parser.add_argument('-s', '--speed', type=str, help='Set color changing speed of smart bulb')
    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.2.1')

    return parser.parse_args(args)

async def main():
    args = parse_args(None)
    wizcon = Wizcon(args.IP)
    await wizcon.run(args)

# Entry point for running launch script after installing package, see setup.py
def main_async():
    return asyncio.run(main())

if __name__ == "__main__":
    asyncio.run(main())



#!/usr/bin/env python3

import sys
import argparse
import unittest
from unittest import IsolatedAsyncioTestCase
from wizcon import wizcon
import pywizlight.scenes

IP = '192.168.0.101'

class TestTurnBulbOn(IsolatedAsyncioTestCase):
    def setUp(self):
        self.wizcon = wizcon.Wizcon(IP)

    async def test_turn_bulb_on(self):
        await self.wizcon.turn_bulb_on()
        state = await self.wizcon.light.updateState()
        response = state.get_state()
        self.assertEqual(response, True)

    def tearDown(self):
        del self.wizcon

class TestTurnBulbOff(IsolatedAsyncioTestCase):
    def setUp(self):
        self.wizcon = wizcon.Wizcon(IP)

    async def test_turn_bulb_off(self):
        await self.wizcon.turn_bulb_off()
        state = await self.wizcon.light.updateState()
        response = state.get_state()
        self.assertEqual(response, False)

    def tearDown(self):
        del self.wizcon

class TestSwitchBulb(IsolatedAsyncioTestCase):
    def setUp(self):
        self.wizcon = wizcon.Wizcon(IP)

    async def test_switch_bulb(self):
        state = await self.wizcon.light.updateState()
        initial_bulb_state = state.get_state()

        await self.wizcon.switch_bulb()
        state = await self.wizcon.light.updateState()
        response = state.get_state()

        if initial_bulb_state is True:
            self.assertFalse(response)
        elif initial_bulb_state is False:
            self.assertTrue(response)
        #else:
        #    error

    def tearDown(self):
        del self.wizcon

class TestSetSceneId(IsolatedAsyncioTestCase):
    def setUp(self):
        self.wizcon = wizcon.Wizcon(IP)
        self.scene_id = 23

    async def test_set_scene_id(self):
        await self.wizcon.set_scene_id(self.scene_id)
        state = await self.wizcon.light.updateState()
        scene_name = state.get_scene()
        scene_id = self.wizcon.light.get_id_from_scene_name(scene_name)
        self.assertEqual(scene_id, self.scene_id)

    def tearDown(self):
        del self.wizcon
        del self.scene_id

class TestSetSceneIdInvalid(IsolatedAsyncioTestCase):
    def setUp(self):
        self.wizcon = wizcon.Wizcon(IP)
        self.scene_id = 0

    async def test_set_scene_id_invalid(self):
        with self.assertRaises(IndexError):
            await self.wizcon.set_scene_id(self.scene_id)

        self.scene_id = 33

        with self.assertRaises(IndexError):
            await self.wizcon.set_scene_id(self.scene_id)

    def tearDown(self):
        del self.wizcon
        del self.scene_id

class TestSetSceneIdAll(IsolatedAsyncioTestCase):
    def setUp(self):
        self.wizcon = wizcon.Wizcon(IP)

    async def test_set_scene_id_all(self):
        for scene_id in pywizlight.scenes.SCENES.keys():
            #if scene_id == 1000:      # Skip scene 1000 Rhythm which fails test
            #    continue

            await self.wizcon.set_scene_id(scene_id)
            state = await self.wizcon.light.updateState()
            scene_name = state.get_scene()
            self.assertEqual(self.wizcon.light.get_id_from_scene_name(scene_name), scene_id)

    def tearDown(self):
        del self.wizcon

class TestSetBrightness(IsolatedAsyncioTestCase):
    def setUp(self):
        self.brightness = 0
        self.wizcon = wizcon.Wizcon(IP)

    async def test_set_brightness(self):
        await self.wizcon.set_brightness(self.brightness)
        state = await self.wizcon.light.updateState()
        brightness_value = state.get_brightness()
        # Valid brightness values are 0-255, but lamp miniumum brightness level is 10% which is 26 hex
        self.assertEqual(brightness_value, 26)

        self.brightness = 26

        await self.wizcon.set_brightness(self.brightness)
        state = await self.wizcon.light.updateState()
        brightness_value = state.get_brightness()
        self.assertEqual(brightness_value, self.brightness)

        self.brightness = 128

        await self.wizcon.set_brightness(self.brightness)
        state = await self.wizcon.light.updateState()
        brightness_value = state.get_brightness()
        self.assertEqual(brightness_value, self.brightness)

        self.brightness = 255

        await self.wizcon.set_brightness(self.brightness)
        state = await self.wizcon.light.updateState()
        brightness_value = state.get_brightness()
        self.assertEqual(brightness_value, self.brightness)

    def tearDown(self):
        del self.brightness
        del self.wizcon

class TestWizconScene(IsolatedAsyncioTestCase):
    def setUp(self):
        self.args = wizcon.parse_args([IP, 'on', '--scene_id=1'])
        self.wizcon = wizcon.Wizcon(IP)

    async def test_wizcon_scene(self):
        await self.wizcon.run(self.args)

        state = await self.wizcon.light.updateState()
        scene_name = state.get_scene()
        self.assertEqual(self.wizcon.light.get_id_from_scene_name(scene_name), self.args.scene_id)

    def tearDown(self):
        del self.args
        del self.wizcon

class TestWizconBrightness(IsolatedAsyncioTestCase):
    def setUp(self):
        self.args = wizcon.parse_args([IP, 'on', '--brightness=28'])
        self.wizcon = wizcon.Wizcon(IP)

    async def test_wizcon_brightness(self):
        await self.wizcon.run(self.args)

        state = await self.wizcon.light.updateState()
        brightness_value = state.get_brightness()
        self.assertEqual(brightness_value, self.args.brightness)

    def tearDown(self):
        del self.args
        del self.wizcon

#class TestTurnBulbOnColor(IsolatedAsyncioTestCase):
#class TestTurnBulbOnBrightnessAndColor(IsolatedAsyncioTestCase):

if __name__ == '__main__':
    unittest.main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="wizcon",
    version="0.2.1",
    author="Robert Gomez, Jr.",
    author_email="rgomezjnr@gmail.com",
    description="Control Philips WiZ Connected smart light bulbs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rgomezjnr/wizcon",
    packages=setuptools.find_packages(),
    python_requires='>=3.6',
    install_requires=["pywizlight"],
    license="MIT",
    entry_points ={'console_scripts':['wizcon=wizcon.wizcon:main_async']},
    keywords="philips wiz wifi wireless home automation cli tool",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "Topic :: Home Automation",
        "Topic :: Utilities",
    ],
)